@@ -38,6 +38,10 @@ class FillerAudioConfig(BaseModel):
         return v
 
 
+class WebhookConfig(BaseModel):
+    url: str
+
+
 class AgentConfig(TypedModel, type=AgentType.BASE):
     initial_message: Optional[BaseMessage] = None
     generate_responses: bool = True
@@ -45,6 +49,7 @@ class AgentConfig(TypedModel, type=AgentType.BASE):
     allow_agent_to_be_cut_off: bool = True
     end_conversation_on_goodbye: bool = False
     send_filler_audio: Union[bool, FillerAudioConfig] = False
+    webhook_config: Optional[WebhookConfig] = None
 
 
 class CutOffResponse(BaseModel):
